@@ -1,4 +1,5 @@
 from contextlib import contextmanager
+import functools
 import socket
 import threading
 import time
@@ -136,7 +137,8 @@ class ServerConnection(threading.Thread):
 
     def add_callback(self, callback: Callable, *args, **kwargs) -> None:
         LOGGER.info(f'Adding callback on {self.server}: {callback}, args: {args}, kwargs: {kwargs}')
-        self._connection.add_callback_threadsafe(lambda: callback(*args, **kwargs))
+        cb = functools.partial(callback, *args, **kwargs)
+        self._connection.add_callback_threadsafe(cb)
 
     def _reconnect_channel(self) -> None:
         self._channel_setup()
